SmsIdpUtils class

Constructors

SmsIdpUtils({required SmsIdpConfig config, required AuthUsers authUsers})

Properties

accountCreation SmsIdpAccountCreationUtil
final
bind SmsIdpBindUtil
final
hashCode int
The hash code for this object.
no setterinherited
hashUtil → Argon2HashUtil
final
login SmsIdpLoginUtil
final
passwordReset SmsIdpPasswordResetUtil
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited