SmsPasswordResetRequestDetachRowRepository class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

authUser(DatabaseSession session, SmsPasswordResetRequest smsPasswordResetRequest, {Transaction? transaction}) Future<void>
Detaches the relation between this SmsPasswordResetRequest and the AuthUser set in authUser by setting the SmsPasswordResetRequest's foreign key authUserId to null.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetChallenge(DatabaseSession session, SmsPasswordResetRequest smsPasswordResetRequest, {Transaction? transaction}) Future<void>
Detaches the relation between this SmsPasswordResetRequest and the SecretChallenge set in resetChallenge by setting the SmsPasswordResetRequest's foreign key resetChallengeId to null.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited