SmsVerifyPasswordResetResult class abstract

短信密码重置验证码验证结果。

Constructors

SmsVerifyPasswordResetResult({String? resetToken, SmsPasswordResetBlockedReason? blockedReason})
factory
SmsVerifyPasswordResetResult.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

blockedReason SmsPasswordResetBlockedReason?
验码成功但被拦截的原因。
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
resetToken String?
验证成功后的 token,用于 finishPasswordReset。
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? resetToken, SmsPasswordResetBlockedReason? blockedReason}) SmsVerifyPasswordResetResult
Returns a shallow copy of this SmsVerifyPasswordResetResult with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
toJsonForProtocol() Map<String, dynamic>
Returns a JSON structure of the model, optimized for Protocol communication.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited